==> Rcmdr_2.2-5.tar.gz: Rcmdr/man/Rcmdr-package.Rd <==
\name{Rcmdr-package}
\alias{Rcmdr-package}
\alias{Rcmdr}
\docType{package}
\title{
R Commander
}
\description{
A platform-independent basic-statistics GUI (graphical
user interface) for R, based on the tcltk package.
}
\details{
\tabular{ll}{
Package: \tab Rcmdr\cr
Version: \tab 2.2-5\cr
Date: \tab 2016-06-14\cr
Depends: \tab R (>= 3.2.0), grDevices, utils, splines, RcmdrMisc (>= 1.0-3), 
  car (>= 2.1-2)\cr
Imports: \tab tcltk, tcltk2 (>= 1.2-6), abind, graphics, methods, stats, relimp (>= 1.0-5)\cr
Suggests: \tab aplpack, colorspace, effects (>= 3.0-1), e1071, foreign, 
  grid, Hmisc, knitr, lattice, leaps, lmtest, markdown, MASS, mgcv, 
  multcomp (>= 0.991-2), nlme, nnet, readxl, relimp,  rgl, rmarkdown (>= 0.9.5), 
  sem (>= 2.1-1) \cr
ByteCompile: \tab yes\cr
License: \tab GPL (>= 2)\cr
URL: \tab http://www.r-project.org,
http://socserv.socsci.mcmaster.ca/jfox/Misc/Rcmdr/\cr
}
}

\references{
Fox, J. (2005) 
The R Commander: A Basic Statistics Graphical User Interface to R. 
\emph{Journal of Statistical Software}, \bold{14(9)}: 1--42.

Fox, J. (2007)
Extending the R Commander by "plug in" packages. 
\emph{R News}, \bold{7(3)}: 46--52.
}

\section{Translations}{
The R Commander comes with translations from English into several other languages. I am grateful to the following individuals and groups for preparing these translations:
Basque, Jose Ramon Rueda;
Brazilian Portuguese, Adriano Azevedo-Filho and Marilia Sa Carvalho;
Catalan, Manel Salamero;
Chinese, Tsungwu Ho, Frank C. S. Liu, and Cheng-shun Lee;
Chinese (Simplified), Shulin Yang;
French, Philippe Grosjean and Milan Bouchet-Valat;
Galician, Anton Meixome;
German: Friedrich Leisch and Gerhard Schoen;
Greek: Vasileios Dimitropoulos, Anastasios Vikatos, and Andreas Vikatos;
Indonesian, I Made Tirta;
Italian, Stefano Calza;
Japanese, Takaharu Araki;
Korean, Chel Hee Lee, Dae-Heung Jang, and Shin Jong-Hwa;
Polish, Lukasz Daniel;
Romanian, Adrian Dusa;
Russian, Alexey Shipunov;
Slovenian, Jaro Lajovic and Matjaz Jeran;
Spanish, Spanish R-UCA Project, http://knuth.uca.es/R.
}

\author{
John Fox <jfox@mcmaster.ca> and Milan Bouchet-Valat, with contributions from Liviu Andronic, Michael Ash, Theophilius Boye, Stefano Calza, Andy Chang, Philippe Grosjean, Richard Heiberger, G. Jay Kerns, Renaud Lancelot, Matthieu Lesnoff, Uwe Ligges, Samir Messad, Martin Maechler, Robert Muenchen, Duncan Murdoch, Erich Neuwirth, Dan Putler, Brian Ripley, Miroslav Ristic,  Peter Wolf, and Kevin Wright.

Maintainer: John Fox <jfox@mcmaster.ca>
}
\keyword{ package }

==> Rcmdr_2.3-0.tar.gz: Rcmdr/man/Rcmdr-package.Rd <==
\name{Rcmdr-package}
\alias{Rcmdr-package}
\alias{Rcmdr}
\docType{package}
\title{
R Commander
}
\description{
A platform-independent basic-statistics GUI (graphical
user interface) for R, based on the tcltk package.
}
\details{
\tabular{ll}{
Package: \tab Rcmdr\cr
Version: \tab 2.3-0\cr
Date: \tab 2016-08-22\cr
Depends: \tab R (>= 3.3.0), grDevices, utils, splines, RcmdrMisc (>= 1.0-5), 
  car (>= 2.1-3)\cr
Imports: \tab tcltk, tcltk2 (>= 1.2-11), abind, graphics, methods, stats, relimp (>= 1.0-5)\cr
Suggests: \tab aplpack, boot, colorspace, effects (>= 3.1-1), e1071, foreign, 
  grid, Hmisc, knitr, lattice, leaps, lmtest, markdown, MASS, mgcv, 
  multcomp (>= 1.4-5), nlme, nnet, nortest, readxl, relimp,  rgl, rmarkdown, 
  sem (>= 3.1-7) \cr
ByteCompile: \tab yes\cr
License: \tab GPL (>= 2)\cr
URL: \tab http://www.r-project.org,
http://socserv.socsci.mcmaster.ca/jfox/Misc/Rcmdr/\cr
}
}

\references{
Fox, J. (2005) 
The R Commander: A Basic Statistics Graphical User Interface to R. 
\emph{Journal of Statistical Software}, \bold{14(9)}: 1--42.

Fox, J. (2007)
Extending the R Commander by "plug in" packages. 
\emph{R News}, \bold{7(3)}: 46--52.
}

\section{Translations}{
The R Commander comes with translations from English into several other languages. I am grateful to the following individuals and groups for preparing these translations:
Basque, Jose Ramon Rueda;
Brazilian Portuguese, Adriano Azevedo-Filho and Marilia Sa Carvalho;
Catalan, Manel Salamero;
Chinese, Tsungwu Ho, Frank C. S. Liu, and Cheng-shun Lee;
Chinese (Simplified), Shulin Yang;
French, Philippe Grosjean and Milan Bouchet-Valat;
Galician, Anton Meixome;
German: Friedrich Leisch and Gerhard Schoen;
Greek: Vasileios Dimitropoulos, Anastasios Vikatos, and Andreas Vikatos;
Indonesian, I Made Tirta;
Italian, Stefano Calza;
Japanese, Takaharu Araki;
Korean, Chel Hee Lee, Dae-Heung Jang, and Shin Jong-Hwa;
Polish, Lukasz Daniel;
Romanian, Adrian Dusa;
Russian, Alexey Shipunov;
Slovenian, Jaro Lajovic and Matjaz Jeran;
Spanish, Spanish R-UCA Project, http://knuth.uca.es/R.
}

\author{
John Fox <jfox@mcmaster.ca> and Milan Bouchet-Valat, with contributions from Liviu Andronic, Michael Ash, Theophilius Boye, Stefano Calza, Andy Chang, Philippe Grosjean, Richard Heiberger, G. Jay Kerns, Renaud Lancelot, Matthieu Lesnoff, Uwe Ligges, Samir Messad, Martin Maechler, Robert Muenchen, Duncan Murdoch, Erich Neuwirth, Dan Putler, Brian Ripley, Miroslav Ristic,  Peter Wolf, and Kevin Wright.

Maintainer: John Fox <jfox@mcmaster.ca>
}
\keyword{ package }
